package Locale::CLDR::Locales::Hu::Any;

# This file auto generated
#	on Sun  3 Dec 10:20:39 am GMT

use version;

our $VERSION = version->declare('v0.34.4');

use v5.10.1;
use mro 'c3';
use if $^V ge v5.12.0, feature => 'unicode_strings';

use Moo;

extends('Locale::CLDR::Locales::Hu');

no Moo;

1;
